@@ -1,4 +1,5 @@
 from __future__ import with_statement
+
 import sqlite3
 
 from code42cli.util import get_user_project_path
@@ -6,7 +7,7 @@ from code42cli.util import get_user_project_path
 _INSERTION_TIMESTAMP_FIELD_NAME = u"insertionTimestamp"
 
 
-class SecurityEventCursorStore(object):
+class BaseCursorStore(object):
     _PRIMARY_KEY_COLUMN_NAME = u"cursor_id"
 
     def __init__(self, db_table_name, db_file_path=None):
@@ -32,6 +33,17 @@ class SecurityEventCursorStore(object):
         with self._connection as conn:
             conn.execute(query, (new_value, primary_key))
 
+    def _row_exists(self, primary_key):
+        query = u"SELECT * FROM {0} WHERE {1}=?"
+        query = query.format(self._table_name, self._PRIMARY_KEY_COLUMN_NAME)
+        with self._connection as conn:
+            cursor = conn.cursor()
+            cursor.execute(query, (primary_key,))
+            query_result = cursor.fetchone()
+            if not query_result:
+                return False
+            return True
+
     def _drop_table(self):
         drop_query = u"DROP TABLE {0}".format(self._table_name)
         with self._connection as conn:
@@ -51,17 +63,18 @@ class SecurityEventCursorStore(object):
                 return int(query_result[0]) <= 0
 
 
-class AEDCursorStore(SecurityEventCursorStore):
-    _PRIMARY_KEY = 1
-
-    def __init__(self, db_file_path=None):
-        super(AEDCursorStore, self).__init__(u"aed_checkpoint", db_file_path)
+class FileEventCursorStore(BaseCursorStore):
+    def __init__(self, profile_name, db_file_path=None):
+        self._primary_key = profile_name
+        super(FileEventCursorStore, self).__init__(u"file_event_checkpoints", db_file_path)
         if self._is_empty():
             self._init_table()
+        if not self._row_exists(self._primary_key):
+            self._insert_new_row()
 
     def get_stored_insertion_timestamp(self):
         """Gets the last stored insertion timestamp."""
-        rows = self._get(_INSERTION_TIMESTAMP_FIELD_NAME, self._PRIMARY_KEY)
+        rows = self._get(_INSERTION_TIMESTAMP_FIELD_NAME, self._primary_key)
         if rows and rows[0]:
             return rows[0][0]
 
@@ -70,17 +83,16 @@ class AEDCursorStore(SecurityEventCursorStore):
         self._set(
             column_name=_INSERTION_TIMESTAMP_FIELD_NAME,
             new_value=new_insertion_timestamp,
-            primary_key=self._PRIMARY_KEY,
+            primary_key=self._primary_key,
         )
 
-    def reset(self):
-        self._drop_table()
-        self._init_table()
-
     def _init_table(self):
         columns = u"{0}, {1}".format(self._PRIMARY_KEY_COLUMN_NAME, _INSERTION_TIMESTAMP_FIELD_NAME)
         create_table_query = u"CREATE TABLE {0} ({1})".format(self._table_name, columns)
-        insert_query = u"INSERT INTO {0} VALUES(?, null)".format(self._table_name)
         with self._connection as conn:
             conn.execute(create_table_query)
-            conn.execute(insert_query, (self._PRIMARY_KEY,))
+
+    def _insert_new_row(self):
+        insert_query = u"INSERT INTO {0} VALUES(?, null)".format(self._table_name)
+        with self._connection as conn:
+            conn.execute(insert_query, (self._primary_key,))
