@@ -1,7 +1,8 @@
-from code42cli.securitydata.logger_factory import get_logger_for_server
-from code42cli.securitydata.arguments import main as main_args
+import code42cli.arguments as main_args
+from code42cli.securitydata.arguments import main as securitydata_main_args
 from code42cli.securitydata.arguments import search as search_args
 from code42cli.securitydata.extraction import extract
+from code42cli.securitydata.logger_factory import get_logger_for_server
 from code42cli.securitydata.options import ServerProtocol
 
 
@@ -16,6 +17,7 @@ def init(subcommand_parser):
     _add_server_arg(parser)
     _add_protocol_arg(parser)
     search_args.add_arguments_to_parser(parser)
+    securitydata_main_args.add_arguments_to_parser(parser)
     main_args.add_arguments_to_parser(parser)
 
 
