@@ -1,7 +1,8 @@
-from code42cli.securitydata.logger_factory import get_logger_for_file
-from code42cli.securitydata.arguments import main as main_args
+import code42cli.arguments as main_args
+from code42cli.securitydata.arguments import main as securitydata_main_args
 from code42cli.securitydata.arguments import search as search_args
 from code42cli.securitydata.extraction import extract
+from code42cli.securitydata.logger_factory import get_logger_for_file
 
 
 def init(subcommand_parser):
@@ -10,10 +11,11 @@ def init(subcommand_parser):
         Args:
             subcommand_parser: The subparsers group created by the parent parser.
     """
-    parser = subcommand_parser.add_parser(u"write-to")
+    parser = subcommand_parser.add_parser("write-to")
     parser.set_defaults(func=write_to)
     _add_filename_subcommand(parser)
     search_args.add_arguments_to_parser(parser)
+    securitydata_main_args.add_arguments_to_parser(parser)
     main_args.add_arguments_to_parser(parser)
 
 
